10030 - Unexpected database error

### Navigation

- index
- next |
- previous |
- fantastico 0.5.0-b126 documentation »
- Fantastico features »
- ROA (Resource Oriented Architecture) »
- ROA Technical Summary »

# 10030 - Unexpected database error

Whenever we try to retrieve / create / update / delete resources database exceptions related to constraint or inconsistencies might appear. This case is treated in a friendly manner within ROA apis. You can find a sample example below:

    {"error_code": 10030,
     "error_description": "Resource /sample-resource version 1.0 can not be created: DB unexpected exception.",
     "error_details": <link to this page>}